      PROGRAM EXP_CALC
C***********************************************************************
C*
C*  PROGRAM TO COMPUTE APPROXIMATE COMPTEL EXPOSURE TO A GIVEN POINT 
C*  IN THE SKY WITHIN AN ANGLE ALFA OF THE COMPTEL POINTING DIRECTION, 
C*  BASED ON THE CURRENT TIMELINE INFORMATION. 
C*                                                                      
C*                                                                      
C*  CALLS  :  FUNCTIONS    EXPFAC, AEFFC                                  
C*            SUBROUTINES  PRTHDR
C*                                                                      
C*                                                                      
C*  INPUT  :   FROM UNIT = 10 - LIST OF OBSERVATIONS FROM TIMELINE
C*             First line contains  information used in the
C*             calculator:
C*             TDATE  = Date of this version of the timeline
C*             CUTOFF = Cutoff in zenith angle for program output
C*             DSSC   = Logical flag to indicate whether this is the
C*                      SSC GRONEWS version ("manual" mode only)
C*             All remaining header lines remain unchanged from those
C*             in timelines originally received from Helmut Steinle/MPE.
C*             All lines which start with "*" are ignored.    
C*             Ends with all items "0" .                                
C*                                                                      
C*
C*             FROM UNIT = 15 - LIST OF SEARCH POSITIONS (Optional)
C*                              (GALACTIC COORDINATES)
C*
C*             Formatted file of GALACTIC COORDINATES (max 200 lines) 
C*             assumed, each line containing:
C*
C*                      glong glat target/postion name
C*                        (real)      (20 char max)   
C*
C*             format:      ( 2(1x,f5.1),1x,a20 )
C*
C*                     xfffffxfffffxaaaaaaaaaaaaaaaaaaaa
C*             sample:  180.0   0.0 Galactic Antictr <-- first line
C*                       90.0 -90.0 S Gal Pole
C*
C*
C*  OUTPUT :   TO UNIT   = 20 - OUTPUT LIST FROM PROGRAM (Optional)
C*                                                                      
C*----------------------------------------------------------------------
C+
C+  VERSION    DATE          COMMENT
C+
C+    0.0   04-mar-94  JGS   This version started by J.G. Stacy,
C+                            based on source code provided by 
C+                            H. Steinle/MPE
C+    0.5   09-mar-94  JGS   "Beta" release at UNH
C+    1.0   11-mar-94  JGS   First distribution to team, SSC
C+    1.1   16-mar-94  JGS   Error-trapping: input coords
C+                            and acos fcn in expfac fcn
C+    1.2   05-dec-94  JGS   Update to include Cycle 4 timeline;
C+                            include version number in printout header;
C+                            pages or skips the intro info.
C+    1.3   25-mar-95  JGS   Change timeline file name; quick update
C+                            for SSC version, for proposers.
C+    1.4   29-jun-95  JGS   Update for use on WWW :
C+                            timeline specified as environment variable;
C+                            timeline dump now a y/n option;
C+                            exp_calc can now be invoked from a shell 
C+                             script (for WWW access);
C+                            update for Cycle 5 addition to timeline.
C+    1.5   09-sep-96  JGS   Annual update, for Cycle 6 addition;
C+                            also, improved error-trapping for
C+                            acos fcn in expfac fcn
C+
C+ Related note regarding input timeline file:
C+                                                                      
C+ Input timeline file is a concatenated version of timelines produced
C+ by Helmut Steinle at MPE for each phase of CGRO observations.
C+ JGS has modified these slightly by adding 2 header lines with info
C+ on timeline date, cutoff angle for computations, and an SSC flag.
C+ Individual lines are ignored in the timeline if they begin with an '*'.
C+ The 'eof' of the input timeline is indicated by 0.0's in the last line.
C+
C***********************************************************************
                                                                        
      IMPLICIT NONE                                                     
C                                                                       
C =========== Variable declaration =====================================
C                                                                       
                                                                        
C---counting variables, logical unit
      INTEGER I,IOBJ,IOBS,LUNOUT,ICUT

C---dummy variables for gal long, gal lat, time and efficiency
C---of single observation                                     
      INTEGER ELI,BI,TIMI,EFFI                                

C---number of objects and observations                                  
      INTEGER NOBJ,NOBS                                      
                                                                        
C---numbers of observations                                             
      REAL NR0(350),NR                                                  
                                                                        
C---see after variable declaration                                      
      REAL ALFA,CUTOFF,BM,ZENANG,EL,B,VERS
                                                                        
C---exposure variables
      REAL EXPFAC,EXP(350),EXP1,EXP2,EXP3,EXP4,EXP5,EXP6,EXPSUM,EXPOS
                                                                        
C---arrays for gal long, lat, time and efficiency of each observation   
      REAL EL0(350),B0(350),TIM0(350),EFF0(350)
                                                                        
C---arrays for gal long, lat of each object                            
      REAL ELOBJCT(200),BOBJCT(200)                                     
                                                                        
C---dummy variable                                                      
C      REAL BUFFER                                                       

C---logical variables
      LOGICAL DBUG,DCONT,DFILE,DOUT,DSSC,DUMP

C---see 'read control file and data'
      CHARACTER*128 TIMEL
      CHARACTER*72 TITLE1
C      CHARACTER*72 TITLE1 , TITLE2 , TITLE3 , TITLE4
C      CHARACTER*72 TITLE5 , TITLE6 , TITLE7 , TITLE8                    
      CHARACTER*72 LINE                                                 
      CHARACTER*48 FILE1,FILE2,COMMI,COMM0(350)
      CHARACTER*20 DATES(350),OBJCT(200),NAME
      CHARACTER*12 FIELD(350)
      CHARACTER*9  TDATE
      CHARACTER*1  ANS,SSC
                                                                        
C---dummy variables                                                     
C      CHARACTER*5  NUMBER                                               
C      CHARACTER*20 COMMENT                                              
                                                                        
      COMMON EL0,B0,TIM0,EFF0,NOBS,ALFA,CUTOFF,BM,ZENANG,EL,B,NAME
                                                                        
C ----------------------------------------------------------------------
C version number of this release of exp_calc
C
      VERS=1.5
C
C convert degrees to rad in REAL*4                
C                                                  
      BM=ATAN(1.)/45.                                                   
C
C specify cut-off angle from instrument zenith
C                                                                        
      ALFA = 50.         
C
C specify cut-off angle for printout of results;
C will also be read in from the first line of the timeline file
C
      CUTOFF = 50.
C
C set default settings of logical flags, output unit
C
      DBUG = .FALSE.
      DCONT= .FALSE.
      DFILE= .FALSE.
      DOUT = .FALSE.
      DSSC = .FALSE.
      DUMP = .FALSE.

      LUNOUT = 6
                                                                        
C====================================================================== 
C     Read control file and data                                        
C====================================================================== 

C                                                                       
C     Open input timeline file
C
      CALL GETENV('EXP_TIMELINE',TIMEL)
      IF(TIMEL .EQ. ' ') TIMEL='comptel_p1234_24jan95'
      OPEN(10,FILE=TIMEL,FORM='FORMATTED',
     &     STATUS='OLD',ERR=900)

C                                                                       
C==== READ TIMELINE FILE =================================================  
C                                                                       
                                                                        
C---- Read title line
                                                                        
      READ(10,109) TITLE1                                               

  109 FORMAT(A72)                                                       

C---- Pick up TDATE, CUTOFF, DSSC info from 1st line of timeline

      READ(TITLE1,580) TDATE,CUTOFF,SSC
 580  FORMAT(18X,A9,12X,F4.1,10X,A1)
      IF(SSC .EQ. 'T' .OR. SSC .EQ. 't') THEN
         DSSC = .TRUE.
      ELSE
         DSSC = .FALSE.
      ENDIF

C---- Print out standard blurb with cutoff limit

      ICUT = NINT(CUTOFF)

      CALL PRTHDR(ICUT,VERS)

C---Read observations 

      WRITE(6,590) TDATE
 590  FORMAT(/' Reading timeline file of date ',A9,' ...')
                                                  
      NOBS=0                                                            
                                                                        
      DO 100 IOBS = 1,350
  101   READ(10,109) LINE                                               
        IF (LINE(1:1).EQ.'*') GO TO 101                                 
        READ(LINE,110) NR,ELI,BI,TIMI,EFFI,COMMI                        
  110   FORMAT(1X,F5.1,2X,4(I3,1X),A48)                                 
C---end of file ?                                                       
        IF (NR.EQ.0.AND.ELI.EQ.0.AND.BI.EQ.0.AND.TIMI.EQ.0              
     &      .AND.EFFI.EQ.0) GO TO 102                                   
        NOBS   = IOBS                                                      
        NR0(IOBS) = NR                                                     
C---fill arrays
        EL0(IOBS) = ELI
        B0(IOBS) = BI
C---- Observation time in days                                          
        TIM0(IOBS) = TIMI/10.                                              
C---- Effectivity value in percent
        EFF0(IOBS)  = EFFI/100.                                            
        COMM0(IOBS) = COMMI
        FIELD(IOBS) = COMMI(1:12)
        DATES(IOBS) = COMMI(14:34)
  100 CONTINUE                                                          
                                                                        
  102 CONTINUE                                                          
                                                                        
      CLOSE(10)

C---- Skip over optional input/output files if this is the SSC version
C     (manual mode only permitted)

      IF(.NOT.DSSC) THEN

      WRITE(6,600) 
 600  FORMAT(/' Do you wish to specify an input file of coordinates',
     &        ' (y or n) ? ',$)
      READ(5,510) ANS
 510  FORMAT(A1)
      IF(ANS .EQ. 'Y' .OR. ANS .EQ. 'y') THEN
         DFILE=.TRUE.
         LUNOUT=20
         WRITE(6,610)
 610     FORMAT(/'*** NOTE ******************************',
     &           '******************************',//
     &           ' Formatted file of GALACTIC COORDINATES',
     &           ' (max 200 lines) assumed,',/
     &           ' each line containing:',//
     &           '          glong glat target/postion name',/
     &           '            (real)      (20 char max)   ',//
     &           ' format:      ( 2(1x,f5.1),1x,a20 )',//
     &           '         xfffffxfffffxaaaaaaaaaaaaaaaaaaaa',/
     &           ' sample:  180.0   0.0 Galactic Antictr',
     &           '     <-- first line of file',/
     &           '           90.0 -90.0 S Gal Pole',//
     &           '***************************************',
     &           '******************************',//
     &           ' Output will be written to file: exposure.lst')
         WRITE(6,620)
 620     FORMAT(/' Enter name of coordinate data file',
     &           ' (48 char max) : ',$)
         READ(5,622) FILE1
 622     FORMAT(A48)
      ELSE
         DFILE=.FALSE.
         WRITE(6,624)
 624     FORMAT(/' Do you wish to direct output to a file',
     &           ' (y or n) ? ',$)
         READ(5,510) ANS
         IF(ANS .EQ. 'Y' .OR. ANS .EQ. 'y') THEN
            DOUT=.TRUE.
            WRITE(6,626)
 626        FORMAT(/' Enter name of output file',
     &           ' (48 char max) : ',$)
            READ(5,622) FILE2
            WRITE(6,628) FILE2
 628        FORMAT(/' Output will be written to file : ',A48)
            LUNOUT=20
         ELSE
            DOUT=.FALSE.
            LUNOUT=6
         ENDIF
      ENDIF

C---- End of specification of optional input/output files

      ENDIF


      WRITE(6,750)
 750  FORMAT(/' Do you want a listing of the complete timeline',
     &        ' used (y or n) ? ',$)
      READ(5,510) ANS
      IF(ANS .EQ. 'Y' .OR. ANS .EQ. 'y') THEN
        DUMP=.TRUE.
      ENDIF
C                                                                       
C==== Read list of search coordinates =================================  
C                                                                       

      IF(DFILE) THEN

         WRITE(6,642) FILE1
 642     FORMAT(/' Reading in list of search coordinates from ',
     &           A48)

         OPEN(15,FILE=FILE1,FORM='FORMATTED',
     &        STATUS='OLD',ERR=910)

         NOBJ = 0                                                          

         DO 500 I = 1,200                                             
            READ(15,502,END=503) ELOBJCT(I),BOBJCT(I),OBJCT(I)
 502        FORMAT(2(1X,F5.1),1X,A20)
C            IF(DBUG) THEN
C               WRITE(6,502) ELOBJCT(I),BOBJCT(I),OBJCT(I)
C            ENDIF
            NOBJ = I
 500     CONTINUE                                                          

 503     CONTINUE

         WRITE(6,644) NOBJ,FILE1
 644     FORMAT(1X,I3,' coordinate pairs found in file ',A48)

         CLOSE(15)

C        IF(DBUG) THEN
C            WRITE(LUNOUT,502) (ELOBJCT(I),BOBJCT(I),OBJCT(I),
C     &                         I=1,NOBJ)
C         ENDIF


      ENDIF

      IF(DFILE) THEN
         OPEN(20,FILE='exposure.lst',FORM='FORMATTED',
     &        STATUS='UNKNOWN',ERR=920)
      ENDIF

      IF(DOUT) THEN
         OPEN(20,FILE=FILE2,FORM='FORMATTED',
     &        STATUS='UNKNOWN',ERR=930)
      ENDIF
                                                    
C                                                                       
C==== Dump input timeline  =========================================== 
C                                                                       
      IF(DUMP .AND. .NOT.DSSC) THEN

      WRITE(LUNOUT,'(/''  LISTING OF COMPLETE TIMELINE USED,''
     &          '' DATED '',A9,'' :''//
     &          ''  NO    VP   GLONG  GLAT  DURAT  EFF.   FIELD''  
     &          ''         DATES''/)') TDATE
      WRITE(LUNOUT,'(I4,1X,F5.1,2X,2F6.1,1X,2F6.2,3X,A12,2X,A20)')       
     &     (I,NR0(I),EL0(I),B0(I),TIM0(I),EFF0(I),FIELD(I),
     &      DATES(I),I=1,NOBS)

      ENDIF

C====================================================================== 
C     Process the List of Observations                                  
C====================================================================== 

      DCONT = .TRUE.

      IOBJ = 1

      DO WHILE (DCONT)

      EXP1=0.0
      EXP2=0.0
      EXP3=0.0
      EXP4=0.0
      EXP5=0.0
      EXP6=0.0
      EXPSUM=0.0


      IF(DFILE) THEN
         EL = ELOBJCT(IOBJ)
         B  = BOBJCT(IOBJ)
         NAME = OBJCT(IOBJ)
      ELSE
 629     CONTINUE
         WRITE(6,630) 
 630     FORMAT(/' Enter position of interest -- ')
         WRITE(6,631)
 631     FORMAT( ' Galactic longitude : ',$)
         READ(5,*) EL
         WRITE(6,632)
 632     FORMAT( ' Galactic latitude  : ',$)
         READ(5,*) B
         IF(EL.GT.360.0 .OR. EL.LT.0.0 .OR. 
     &       B.GT.90.0  .OR. B.LT.-90.0 .AND.
     &       .NOT.DFILE) THEN
            WRITE(6,634) EL,B
 634        FORMAT(/' Glong and/or Glat outside of permitted range ',
     &      ' (L:0-->360,B:-90-->+90) : ',/,2(1X,F8.2))
            GOTO 629
         ENDIF
         WRITE(6,635)
 635     FORMAT(/' Enter (optional) target/object name for',
     &           ' this position (20 char max) :')
         READ(5,636) NAME
 636     FORMAT(A20)
      ENDIF

         WRITE(6,640) EL,B,NAME
 640     FORMAT(' L=',F6.2,' B=',F6.2,3X,A20)

C
C write out header lines
C
      
      WRITE(LUNOUT,645) EL,B,NAME,CUTOFF
 645  FORMAT(/' ============================================',
     &        '============================',/
     &        ' COMPTEL EXPOSURE SUMMARY FOR POSITION : (L,B) = (',
     &        F6.2,',',F6.2,')',/
     &        '                                  NAME :  ',A20,//
     &        ' NOTE: EFFECTIVE EXPOSURE TIMES ARE CALCULATED FOR',
     &        ' THOSE VIEWING'/ 
     &        '       PERIODS WITH POINTING DIRECTIONS WITHIN ',
     &          F4.1,' DEG OF THE'/
     &        '       SPECIFIED POSITION',//
C     &        ' NOTE2: EXPOSURES ARE EXPRESSED AS',
C     &        ' ''EFFECTIVE DAYS'' ',//
     &        3X,'VP',3X,'FIELD',17X,'DATES',10X,'GLONG',4X,'GLAT',
     &        2X,'Z.A.',3X,'EXPOS',/
     &        50X,' (degrees)       (days) ',/
     &        ' ============================================',
     &        '============================'/)

      DO 210 IOBS=1,NOBS
         
         EXPOS=EXPFAC(IOBS,DBUG)
         EXP(IOBS)=EXPOS
         IF(ZENANG .LE. CUTOFF .AND. EXPOS .GT. 0.0) THEN
C
C PRINT OUT CALCULATION FOR THIS VIEWING PERIOD
C
            WRITE(LUNOUT,650) NR0(IOBS),FIELD(IOBS),DATES(IOBS),
     &                        EL0(IOBS),B0(IOBS),ZENANG,EXP(IOBS)
 650        FORMAT(1X,F5.1,2X,A12,2X,A20,2(2X,F6.2),2X,F4.1,2X,F6.2)
C
C ACCUMULATE EXPOSURE ARRAYS
C
            EXPSUM=EXPSUM+EXPOS
            IF(NR0(IOBS) .LT. 200.0) THEN
               EXP1=EXP1+EXPOS
            ELSE IF(NR0(IOBS) .LT. 300.0) THEN
               EXP2=EXP2+EXPOS
            ELSE IF(NR0(IOBS) .LT. 400.0) THEN
               EXP3=EXP3+EXPOS
            ELSE IF(NR0(IOBS) .LT. 500.0) THEN
               EXP4=EXP4+EXPOS
            ELSE IF(NR0(IOBS) .LT. 600.0) THEN
               EXP5=EXP5+EXPOS
            ELSE
               EXP6=EXP6+EXPOS
            ENDIF
         ENDIF
 210     CONTINUE

C
C WRITE SUMMARY INFO
C

         WRITE(LUNOUT,660) EXP1,EXP1*86400.,EXP2,EXP2*86400.,
     &                     EXP3,EXP3*86400.,EXP4,EXP4*86400.,
     &                     EXP5,EXP5*86400.,EXP6,EXP6*86400.,
     &                     EXPSUM,EXPSUM*86400.
 660     FORMAT(/' EFF EXPOSURE TIME, PHASE 1 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' EFF EXPOSURE TIME, PHASE 2 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' EFF EXPOSURE TIME, PHASE 3 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' EFF EXPOSURE TIME, CYCLE 4 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' EFF EXPOSURE TIME, CYCLE 5 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' EFF EXPOSURE TIME, CYCLE 6 : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',//
     &           ' TOTAL EFF EXPOSURE TIME    : ',F6.2,' days = ',
     &             1PE8.2,0P,' s',/
     &           ' (ALL PHASES)'//
     &           ' ============================================',
     &           '============================'/)


         IF(DFILE) THEN
            IF(IOBJ. LT. NOBJ) THEN
               DCONT=.TRUE.
               IOBJ=IOBJ+1
            ELSE
               DCONT=.FALSE.
            ENDIF
         ELSE
            WRITE(6,670)
 670        FORMAT(' Try another position ? ',$)
            READ(5,510) ANS
            IF(ANS .EQ. 'Y' .OR. ANS .EQ. 'y') THEN
               DCONT=.TRUE.
            ELSE
               DCONT=.FALSE.
            ENDIF
         ENDIF
      ENDDO

      IF(DFILE) THEN
         CLOSE(20)
         WRITE(6,690) 
 690     FORMAT(/' Done. Output is in the file exposure.lst'/)
      ENDIF



      IF(DOUT) THEN
         CLOSE(20)
         WRITE(6,695) FILE2
 695     FORMAT(/' Done. Output is in the file ',A48/)
      ENDIF


 999  CONTINUE                                                          
      STOP                                                              

 900  CONTINUE
      WRITE(6,902)
 902  FORMAT(/' STOP: ERROR OPENING TIMELINE FILE')
      STOP

 910  CONTINUE
      WRITE(6,912) FILE1
 912  FORMAT(/' STOP: ERROR OPENING INPUT COORDINATE FILE ',A48)
      STOP

 920  CONTINUE
      WRITE(6,922)
 922  FORMAT(/' STOP: ERROR OPENING OUTPUT FILE EXPOSURE.LST')
      STOP

 930  CONTINUE
      WRITE(6,932) FILE2
 932  FORMAT(/' STOP: ERROR OPENING OUTPUT FILE ',A48)
      STOP

      END                                                               
                                                                        
C############# end of main program #################################### 
                                                                        
                                                                        
C=======================================================================
C             Functions                                                 
C=======================================================================
      FUNCTION EXPFAC(IOBS,DBUG)
C                                                                       
C  FUNCTION TO RETURN THE EXPOSURE AT USER-SPECIFIED POINT EL,B
C  (TRANSMITTED IN COMMON) FOR VIEWING PERIOD IOBS 
C                                                                       
      INTEGER IOBS
      REAL EL0(350),B0(350),TIM0(350),EFF0(350),ZENANG,EL,B
      CHARACTER*20 NAME
      LOGICAL DBUG

      COMMON EL0,B0,TIM0,EFF0,NOBS,ALFA,CUTOFF,BM,ZENANG,EL,B,NAME
C                                                                       
      IF(EL0(IOBS).EQ.EL .AND. B0(IOBS).EQ.B) THEN
         ZENANG=0.0
      ELSE
        CI=COS(EL*BM)*COS(B*BM)                                         
        CJ=SIN(EL*BM)*COS(B*BM)                                         
        CK=SIN(B*BM)                                                    
C                                                                       
        CI0=COS(EL0(IOBS)*BM)*COS(B0(IOBS)*BM)                                
        CJ0=SIN(EL0(IOBS)*BM)*COS(B0(IOBS)*BM)                                
        CK0=SIN(B0(IOBS)*BM)
        ARG=CI*CI0+CJ*CJ0+CK*CK0
C        IF(DBUG) THEN
C           WRITE (6,*) CI,CJ,CK,CI0,CJ0,CK0
C           WRITE (6,*) ARG
C        ENDIF
        IF( ARG .LT. -1.0 ) THEN
           IF (DBUG) WRITE  (6,*) ARG
           ARG = -1.0
        ENDIF
        IF( ARG .GT. 1.0 ) THEN
           IF (DBUG) WRITE  (6,*) ARG
           ARG = 1.0
        ENDIF
        ZENANG=ACOS(ARG)/BM
      ENDIF
      IF(ZENANG.LE.ALFA) THEN
        EXPFAC=TIM0(IOBS)*EFF0(IOBS)*AEFFC(ZENANG)
      ELSE
        EXPFAC=0.0
      ENDIF

      RETURN                                                            
      END                                                               
C-----------------------------------------------------------------------
      FUNCTION AEFFC(ZENANG)                                               
C                                                                       
C   Effective area:                                                     
C   first version - constant 20 cm**2;                                  
C   second version - a triangle of width 50 degrees, which is a very    
C   good approximation to the geometry function as derived by Martin    
C   Varendorff. He used a 15 degree smearing folded with the geometry   
C   function.                                                           
C   (arbitrary units - only the form is relevant)                       
C                                                                       
C     AEFFC = 20.0
C                                             
      AEFFC = 1.0 - (ZENANG/50.)                                           
      IF(AEFFC.LT.0.D0) AEFFC = 0.D0                                    
      RETURN                                                            
      END                                                               
C-----------------------------------------------------------------------
      SUBROUTINE PRTHDR(ICUT,VERS)

      INTEGER ICUT
      REAL    VERS
      CHARACTER*1 ANS

      WRITE(6,600) VERS
 600  FORMAT(/
     & ' ============================================',
     & '============================'/
     & 10x,'***** COMPTEL EXPOSURE CALCULATOR (Version ',F3.1,') ',
     & '*****',/
     & ' ============================================',
     & '============================'/)

      WRITE(6,602)
 602  FORMAT(' NOTE1: This version of the exposure calculator',
     &' (still) assumes',/
     &       '        GALACTIC COORDINATES throughout.',//
     &       ' NOTE2: I/O DATASET OPTIONS DISABLED DURING WWW USE.',//
     &' (Enter ''s'' to skip the explanatory introduction,',
     & /     '  or ''p'' to print it to your screen.) ',$)
      READ(5,510) ANS
 510  FORMAT(A1)
      IF(ANS .EQ. 'S' .OR. ANS .EQ. 's') THEN
	RETURN
      ELSE
        CONTINUE
      ENDIF

      WRITE(6,604) ICUT
604   FORMAT(/
     & ' This utility returns the approximate COMPTEL',
     & ' ''exposure'' obtained to date',/
     & ' for a user-specified point on the sky. The',
     & ' present version calculates',/
     & ' the effective time that a particular target',
     & ' position falls within ',I2,/
     & ' degrees of the instrument pointing direction.'
     & '  Note that this routine is',/
     & ' intended primarily as a proposal-preparation',
     & ' tool and as a utility to aid',/
     & ' in identifying those viewing periods during',
     & ' which maximum COMPTEL exposure',/
     & ' was obtained for a particular target.  It is',
     & ' NOT intended for detailed',/
     & ' scientific analysis.',
     & /)

      WRITE(6,605)
605   FORMAT(' (Enter ''c'' to continue, or ''s'' to skip the rest',
     & ' of the introduction.) ',$)
      READ(5,510) ANS
      IF(ANS .EQ. 'S' .OR. ANS .EQ. 's') THEN
	RETURN
      ELSE
        CONTINUE
      ENDIF

      WRITE(6,610)
 610  FORMAT(/
     & ' This routine assumes a simple triangular',
     & ' response to off-axis incident',/
     & ' radiation; this has been found to be a',
     & ' reasonable first approximation',/
     & ' to the true angular response of COMPTEL.',
     & ' Also, an ''effectivity'' factor',/
     & ' has been estimated for each viewing period,',
     & ' which represents that fraction',/
     & ' of the total observing time during which',
     & ' COMPTEL is actually viewing the',/ 
     & ' target region (i.e., outside the SAA,',
     & ' unobstructed by the Earth).',/
     & ' Due to the large field of view of COMPTEL,'
     & ' this fraction never exceeds',/
     & ' 45 percent of the total observing time for',
     & ' a given viewing period.')
      WRITE(6,612)
 612  FORMAT(
     & ' This factor also includes an estimate of',
     & ' the fraction of time lost',/
     & ' due to on-board tape-recorder problems,',
     & ' and the lack of complete',/
     & ' real-time TDRSS coverage of the spacecraft',
     & ' telemetry.',
     & /)

      WRITE(6,605)
      READ(5,510) ANS
      IF(ANS .EQ. 'S' .OR. ANS .EQ. 's') THEN
	RETURN
      ELSE
        CONTINUE
      ENDIF

      WRITE(6,620)
 620  FORMAT(/
     & ' Note that this utility returns the ''effective',
     & ' time'' (Teff) that a',/
     & ' target position lies within the field of view',
     & ' of COMPTEL. An estimate',/
     & ' of ''effective detector area'' (Aeff) is also',
     & ' required to derive an',/ 
     & ' estimate of the true ''effective exposure''',
     & ' (Aeff*Teff, units: cm**2 s).',/
     & ' The following values for Aeff are valid over',
     & ' the standard COMPTEL energy',/
     & ' ranges, for an on-axis source, after application',
     & ' of standard COMPTEL',/ 
     & ' event-selection criteria: 0.75-1 MeV: 6 cm**2;',
     & ' 1-3 MeV: 10 cm**2;',/ 
     & ' 3-10 MeV: 18 cm**2; 10-30 MeV: 27 cm**2 (refer',
     & ' to the COMPTEL instrument',/
     & ' description by Schoenfelder et al. 1993,',
     & ' Ap.J.Suppl. 86, 657). ',
     & /)

      WRITE(6,630)
 630  FORMAT( 
     & ' This utility is based on timeline-related',
     & ' software originally developed',/
     & ' by Helmut Steinle of MPE. All comments and',
     & ' suggestions for improvements',/
     & ' to this exposure calculator should be sent to',
     & ' the COMPTEL Instrument',/ 
     & ' Specialist, J. Gregory Stacy (Greg.Stacy@unh.edu).'//
     & ' ============================================',
     & '============================')

      RETURN
      END
